==> firefox-112.0.source.tar.xz: firefox-112.0/remote/test/puppeteer/packages/puppeteer-core/src/common/common.ts <==
/**
 * Copyright 2022 Google Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export * from './Accessibility.js';
export * from './AriaQueryHandler.js';
export * from './Browser.js';
export * from './BrowserConnector.js';
export * from './BrowserWebSocketTransport.js';
export * from './ChromeTargetManager.js';
export * from './Configuration.js';
export * from './Connection.js';
export * from './ConnectionTransport.js';
export * from './ConsoleMessage.js';
export * from './Coverage.js';
export * from './CustomQueryHandler.js';
export * from './Debug.js';
export * from './Device.js';
export * from './Dialog.js';
export * from './ElementHandle.js';
export * from './EmulationManager.js';
export * from './Errors.js';
export * from './EventEmitter.js';
export * from './ExecutionContext.js';
export * from './fetch.js';
export * from './FileChooser.js';
export * from './FirefoxTargetManager.js';
export * from './Frame.js';
export * from './FrameManager.js';
export * from './FrameTree.js';
export * from './HTTPRequest.js';
export * from './HTTPResponse.js';
export * from './Input.js';
export * from './IsolatedWorld.js';
export * from './IsolatedWorlds.js';
export * from './JSHandle.js';
export * from './LazyArg.js';
export * from './LifecycleWatcher.js';
export * from './NetworkEventManager.js';
export * from './NetworkManager.js';
export * from './NodeWebSocketTransport.js';
export * from './Page.js';
export * from './PDFOptions.js';
export * from './PredefinedNetworkConditions.js';
export * from './Product.js';
export * from './Puppeteer.js';
export * from './PuppeteerViewport.js';
export * from './SecurityDetails.js';
export * from './Target.js';
export * from './TargetManager.js';
export * from './TaskQueue.js';
export * from './TimeoutSettings.js';
export * from './Tracing.js';
export * from './types.js';
export * from './USKeyboardLayout.js';
export * from './util.js';
export * from './WaitTask.js';
export * from './WebWorker.js';

==> firefox-121.0.source.tar.xz: firefox-121.0/remote/test/puppeteer/packages/puppeteer-core/src/common/common.ts <==
/**
 * Copyright 2022 Google Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export * from './Accessibility.js';
export * from './AriaQueryHandler.js';
export * from './Binding.js';
export * from './Browser.js';
export * from './BrowserConnector.js';
export * from './BrowserWebSocketTransport.js';
export * from './ChromeTargetManager.js';
export * from './Configuration.js';
export * from './Connection.js';
export * from './ConnectionTransport.js';
export * from './ConsoleMessage.js';
export * from './Coverage.js';
export * from './CustomQueryHandler.js';
export * from './Debug.js';
export * from './Device.js';
export * from './DeviceRequestPrompt.js';
export * from './Dialog.js';
export * from './ElementHandle.js';
export * from './EmulationManager.js';
export * from './Errors.js';
export * from './EventEmitter.js';
export * from './ExecutionContext.js';
export * from './fetch.js';
export * from './FileChooser.js';
export * from './FirefoxTargetManager.js';
export * from './FrameManager.js';
export * from './FrameTree.js';
export * from './Input.js';
export * from './IsolatedWorld.js';
export * from './IsolatedWorlds.js';
export * from './JSHandle.js';
export * from './LazyArg.js';
export * from './LifecycleWatcher.js';
export * from './NetworkEventManager.js';
export * from './NetworkManager.js';
export * from './NodeWebSocketTransport.js';
export * from './Page.js';
export * from './PDFOptions.js';
export * from './PredefinedNetworkConditions.js';
export * from './Product.js';
export * from './Puppeteer.js';
export * from './PuppeteerViewport.js';
export * from './QueryHandler.js';
export * from './SecurityDetails.js';
export * from './Target.js';
export * from './TargetManager.js';
export * from './TaskQueue.js';
export * from './TimeoutSettings.js';
export * from './Tracing.js';
export * from './types.js';
export * from './USKeyboardLayout.js';
export * from './util.js';
export * from './WaitTask.js';
export * from './WebWorker.js';
